@@ -4,7 +4,7 @@ use warnings;
 
 package Crypt::Diceware::Wordlist::Beale;
 # ABSTRACT: Crypt::Diceware wordlist from the alternative Diceware list
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our @Words = qw{
   a a's a-1 a-z aa aaa aaaa aaron ab aback abacus abase abash abate abbey
@@ -571,7 +571,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -579,7 +579,7 @@ Crypt::Diceware::Wordlist::Beale - Crypt::Diceware wordlist from the alternative
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -610,10 +610,6 @@ L<Crypt::Diceware>
 
 David Golden <dagolden@cpan.org>
 
-=head1 CONTRIBUTOR
-
-Neil Bowers <neil@bowers.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
