@@ -4,7 +4,7 @@ use warnings;
 
 package Crypt::Diceware::Wordlist::Original;
 # ABSTRACT: Crypt::Diceware wordlist from the original Diceware list
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our @Words = qw{
   a a&p a's aa aaa aaaa aaron ab aba ababa aback abase abash abate abbas abbe
@@ -584,7 +584,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -592,7 +592,7 @@ Crypt::Diceware::Wordlist::Original - Crypt::Diceware wordlist from the original
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -622,10 +622,6 @@ L<Crypt::Diceware>
 
 David Golden <dagolden@cpan.org>
 
-=head1 CONTRIBUTOR
-
-Neil Bowers <neil@bowers.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
